@@ -1,3 +1,4 @@
+use core::fmt;
 use core::iter::FusedIterator;
 use core::marker::PhantomData;
 use core::mem::MaybeUninit;
@@ -167,22 +168,21 @@ impl<T, const N: usize> Deque<T, N> {
 
     /// Returns a pair of mutable slices which contain, in order, the contents of the `Deque`.
     pub fn as_mut_slices(&mut self) -> (&mut [T], &mut [T]) {
+        let ptr = self.buffer.as_mut_ptr();
+
         // NOTE(unsafe) avoid bound checks in the slicing operation
         unsafe {
             if self.is_empty() {
                 (&mut [], &mut [])
             } else if self.back <= self.front {
                 (
-                    slice::from_raw_parts_mut(
-                        self.buffer.as_mut_ptr().add(self.front) as *mut T,
-                        N - self.front,
-                    ),
-                    slice::from_raw_parts_mut(self.buffer.as_mut_ptr() as *mut T, self.back),
+                    slice::from_raw_parts_mut(ptr.add(self.front) as *mut T, N - self.front),
+                    slice::from_raw_parts_mut(ptr as *mut T, self.back),
                 )
             } else {
                 (
                     slice::from_raw_parts_mut(
-                        self.buffer.as_mut_ptr().add(self.front) as *mut T,
+                        ptr.add(self.front) as *mut T,
                         self.back - self.front,
                     ),
                     &mut [],
@@ -350,7 +350,7 @@ impl<T, const N: usize> Deque<T, N> {
         let done = self.is_empty();
         IterMut {
             _phantom: PhantomData,
-            buffer: &mut self.buffer[0] as *mut MaybeUninit<T>,
+            buffer: &mut self.buffer as *mut _ as *mut MaybeUninit<T>,
             front: self.front,
             back: self.back,
             done,
@@ -374,6 +374,12 @@ impl<T, const N: usize> Drop for Deque<T, N> {
     }
 }
 
+impl<T: fmt::Debug, const N: usize> fmt::Debug for Deque<T, N> {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        f.debug_list().entries(self).finish()
+    }
+}
+
 /// An iterator that moves out of a [`Deque`].
 ///
 /// This struct is created by calling the `into_iter` method.
